@@ -1,6 +1,5 @@
 import configparser
 import os
-import sys
 import time
 from datetime import datetime
 from pathlib import Path
@@ -8,7 +7,9 @@ from typing import Optional, Tuple
 
 import click
 import yaml
-from pydantic import BaseModel
+from pydantic import BaseModel, ValidationError  # type: ignore
+
+from treebeard.util import fatal_exit
 
 
 class TreebeardEnv(BaseModel):
@@ -68,7 +69,7 @@ def get_config_path():
 
 
 def validate_notebook_directory(
-    treebeard_env: TreebeardEnv, treebeard_config: Optional[TreebeardConfig]
+    treebeard_env: TreebeardEnv, treebeard_config: TreebeardConfig
 ):
     if treebeard_env.project_id is None:
         click.echo(
@@ -78,28 +79,25 @@ def validate_notebook_directory(
             )
         )
 
-    if treebeard_config:
-        if os.path.exists(treebeard_config.notebook):
-            return
-    else:
-        if os.path.exists("main.ipynb"):
-            return
-
-    sys.exit(1)
-    click.echo(
-        "Fatal: This command must be run in a directory containing a main.ipynb file or valid treebeard.yaml"
-    )
-    sys.exit(1)
+    if not os.path.exists(treebeard_config.notebook):
+        fatal_exit(
+            f"Cannot run non-existent notebook '{treebeard_config.notebook}', are you missing a treebeard.yaml file?"
+        )
 
 
-def get_treebeard_config() -> Optional[TreebeardConfig]:
+def get_treebeard_config() -> TreebeardConfig:
     notebook_config = "treebeard.yaml"
     if not os.path.exists(notebook_config):
-        return None
+        return TreebeardConfig()
 
     with open(notebook_config) as f:
         conf = yaml.load(f, Loader=yaml.FullLoader)
-        return TreebeardConfig(**conf)
+        if not conf:
+            fatal_exit("treebeard.yaml config file exists but is empty")
+        try:
+            return TreebeardConfig(**conf)
+        except ValidationError as e:  # type: ignore
+            fatal_exit(f"Error parsing treebeard.yaml\n{e.json()}")
 
 
 def get_treebeard_env():
@@ -136,7 +134,6 @@ def get_treebeard_env():
 config_path = get_config_path()
 treebeard_config = get_treebeard_config()
 treebeard_env = get_treebeard_env()
-click.echo(f"Treebeard env is {treebeard_env}")
 run_path = get_run_path(treebeard_env)
 secrets_endpoint = f"{url}/projects/{treebeard_env.project_id}/notebooks/{treebeard_env.notebook_id}/secrets"
 notebooks_endpoint = f"{url}/notebooks/{treebeard_env.notebook_id}"
