@@ -18,6 +18,7 @@ from halo import Halo  # type: ignore
 from humanfriendly import format_size, parse_size  # type: ignore
 from timeago import format as timeago_format  # type: ignore
 
+from treebeard.buildtime.run_repo import run_repo
 from treebeard.conf import (
     config_path,
     get_time,
@@ -29,6 +30,7 @@ from treebeard.conf import (
 from treebeard.helper import CliContext
 from treebeard.notebooks.types import Run
 from treebeard.secrets.helper import get_secrets_archive
+from treebeard.util import fatal_exit
 
 pp = pprint.PrettyPrinter(indent=2)
 
@@ -110,7 +112,7 @@ def run(cli_context: CliContext, t: str, watch: bool, ignore: List[str], local:
     size = os.path.getsize(src_archive.name)
     max_upload_size = "100MB"
     if size > parse_size(max_upload_size):
-        click.echo(
+        fatal_exit(
             click.style(
                 (
                     f"ERROR: Compressed notebook directory is {format_size(size)},"
@@ -120,49 +122,26 @@ def run(cli_context: CliContext, t: str, watch: bool, ignore: List[str], local:
                 fg="red",
             )
         )
-        quit(1)
 
     if local:
         spinner.stop()
-        spinner: Any = Halo(text="🌲  Compressing Secrets\n", spinner="dots")
-        # spinner.start()
-        # os.chdir(tempfile.gettempdir())
-        client: Any = docker.from_env()  # type: ignore
-        builder_image_name = "gcr.io/treebeard-259315/image-builder"
-        # client.images.pull(builder_image_name)
-        secrets_archive = get_secrets_archive()
-
         build_tag = str(time.mktime(datetime.today().timetuple()))
-        env_vars = {
-            "TREEBEARD_PROJECT_ID": project_id,
-            "TREEBEARD_NOTEBOOK_ID": notebook_id,
-            "TREEBEARD_REPO_URL": f"file://{src_archive.name}",
-            "TREEBEARD_SECRETS_URL": f"file://{secrets_archive.name}",
-            "TREEBEARD_BUILD_TAG": build_tag,
-        }
-        if cli_context.debug:
-            click.echo(f"Env vars:\n{pp.pformat(env_vars)}")
-
-        click.echo("🌲  Building Image Locally\n")
-        docker_socket = "/var/run/docker.sock"
         repo_image_name = (
             f"gcr.io/treebeard-259315/projects/{project_id}/{notebook_id}:{build_tag}"
         )
-        click.echo(f"Building {repo_image_name}")
-
-        container = client.containers.run(
-            builder_image_name,
-            "python -m treebeard.buildtime.run_repo",
-            environment=env_vars,
-            volumes={
-                src_archive.name: {"bind": src_archive.name, "mode": "ro"},
-                secrets_archive.name: {"bind": secrets_archive.name, "mode": "ro"},
-                docker_socket: {"bind": docker_socket, "mode": "rw"},
-            },
-            detach=True,
+        click.echo(f"🌲  Building {repo_image_name} Locally\n")
+        secrets_archive = get_secrets_archive()
+        repo_url = f"file://{src_archive.name}"
+        secrets_url = f"file://{secrets_archive.name}"
+        run_repo(
+            str(project_id),
+            str(notebook_id),
+            treebeard_env.run_id,
+            build_tag,
+            repo_url,
+            secrets_url,
+            local=True,
         )
-
-        [click.echo(line, nl=False) for line in container.logs(stream=True)]
         sys.exit(0)
 
     spinner.text = "🌲  submitting notebook to runner\n"
@@ -199,9 +178,7 @@ def run(cli_context: CliContext, t: str, watch: bool, ignore: List[str], local:
                 # spinner.stop()
                 click.echo(f"Build result: {build_result}")
             elif status in ["FAILURE", "TIMEOUT", "INTERNAL_ERROR", "CANCELLED"]:
-                click.echo(f"Build failed")
-                build_result = status
-                sys.exit(1)
+                fatal_exit(f"Build failed")
 
 
 @click.command()
@@ -211,7 +188,7 @@ def cancel():
     spinner: Any = Halo(text="cancelling", spinner="dots")
     click.echo(f"🌲  Cancelling {notebook_id}")
     spinner.start()
-    requests.delete(notebooks_endpoint, headers=treebeard_env)  # type: ignore
+    requests.delete(notebooks_endpoint, headers=treebeard_env.dict())
     spinner.stop()
     click.echo(f"🛑 Done!")
 
@@ -226,10 +203,9 @@ def status():
 
     json_data = json.loads(response.text)
     if len(json_data) == 0:
-        click.echo(
+        fatal_exit(
             "This notebook has not been run. Try running it with `treebeard run`"
         )
-        quit(1)
     click.echo("🌲  Recent runs:\n")
 
     max_results = 5
