@@ -20,7 +20,7 @@ def secrets():
 @secrets.command()
 @click.argument("files", type=click.File("r"), nargs=-1)
 def push(files: List[IO]):
-    """Uploads json document of secrets to Treebeard's servers. These will be available in your notebook directory at runtime"""
+    """Uploads files marked in treebeard.yaml as 'secret'"""
     click.echo(f"🌲 Pushing Secrets for project {treebeard_env.project_id}")
     validate_notebook_directory(treebeard_env, treebeard_config)
     secrets_archive = get_secrets_archive(files)
